==> bib2html-1.1.tbz: lib/perl5/site_perl/5.8.6/Bib2HTML/Release.pm <==
# Copyright (C) 2002-03  Stephane Galland <galland@arakhne.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

package Bib2HTML::Release;
@ISA = ('Exporter');
@EXPORT = qw( &getVersionNumber &getVersionDate &getBugReportURL
	      &getAuthorName &getAuthorEmail &getMainURL 
	      &getContributors ) ;
@EXPORT_OK = qw();
use strict;
use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
my $VERSION = "0.2" ;

#------------------------------------------------------
#
# DEFINITIONS
#
#------------------------------------------------------

my $BIB2HTML_VERSION      = '1.1' ;
my $BIB2HTML_DATE         = '2004/04/26' ;
my $BIB2HTML_BUG_URL      = 'http://www.arakhne.org/bugtrack/' ;
my $BIB2HTML_AUTHOR       = 'Stphane GALLAND' ;
my $BIB2HTML_AUTHOR_EMAIL = 'galland@arakhne.prg' ;
my $BIB2HTML_URL          = 'http://www.arakhne.org/tools/bib2html/' ;
my %BIB2HTML_CONTRIBS     = ( 'zinser@zinser.no-ip.info' => "Martin P.J. ZINSER",
			      'preining@logic.at' => "Norbert PREINING",
			    ) ;

#------------------------------------------------------
#
# Functions
#
#------------------------------------------------------

sub getVersionNumber() {
  return $BIB2HTML_VERSION ;
}

sub getVersionDate() {
  return $BIB2HTML_DATE ;
}

sub getBugReportURL() {
  return $BIB2HTML_BUG_URL ;
}

sub getAuthorName() {
  return $BIB2HTML_AUTHOR ;
}

sub getAuthorEmail() {
  return $BIB2HTML_AUTHOR_EMAIL ;
}

sub getMainURL() {
  return $BIB2HTML_URL ;
}

sub getContributors() {
  return %BIB2HTML_CONTRIBS ;
}

1;
__END__

==> bib2html-3.3.tbz: lib/perl5/site_perl/5.8.8/Bib2HTML/Release.pm <==
# Copyright (C) 2002-03  Stephane Galland <galland@arakhne.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

package Bib2HTML::Release;
@ISA = ('Exporter');
@EXPORT = qw( &getVersionNumber &getVersionDate &getBugReportURL
	      &getAuthorName &getAuthorEmail &getMainURL 
	      &getContributors ) ;
@EXPORT_OK = qw();
use strict;
use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
my $VERSION = "0.2" ;

#------------------------------------------------------
#
# DEFINITIONS
#
#------------------------------------------------------

my $BIB2HTML_VERSION      = '3.3' ;
my $BIB2HTML_DATE         = '2005/02/14' ;
my $BIB2HTML_BUG_URL      = 'http://www.arakhne.org/bib2html/submitbug.html' ;
my $BIB2HTML_AUTHOR       = 'Stphane GALLAND' ;
my $BIB2HTML_AUTHOR_EMAIL = 'galland@arakhne.org' ;
my $BIB2HTML_URL          = 'http://www.arakhne.org/bib2html/' ;
my %BIB2HTML_CONTRIBS     = ( 'zinser@zinser.no-ip.info' => "Martin P.J. ZINSER",
			      'preining@logic.at' => "Norbert PREINING",
			      'sebastian.rodriguez@utbm.fr' => "Sebastian RODRIGUEZ",
			      'michail@mpi-sb.mpg.de' => "Dimitris MICHAIL",
			      'joao.lourenco@di.fct.unl.pt' => "Joao LOURENCO",
			    ) ;

#------------------------------------------------------
#
# Functions
#
#------------------------------------------------------

sub getVersionNumber() {
  return $BIB2HTML_VERSION ;
}

sub getVersionDate() {
  return $BIB2HTML_DATE ;
}

sub getBugReportURL() {
  return $BIB2HTML_BUG_URL ;
}

sub getAuthorName() {
  return $BIB2HTML_AUTHOR ;
}

sub getAuthorEmail() {
  return $BIB2HTML_AUTHOR_EMAIL ;
}

sub getMainURL() {
  return $BIB2HTML_URL ;
}

sub getContributors() {
  return %BIB2HTML_CONTRIBS ;
}

1;
__END__
